/**
 * Unboxed primitive types.
 *
 * We use boxed primitive types where possible, to achieve nominal typing for extra type safety. However, TSOA does not
 * recognise these, so we provide unboxed variants here that we can attach OpenAPI specification metadata to.
 */
export type IgnoreMeUnboxed = never; // Required, else above doc-comment wipes-out the next type's generated spec.

/**
 * Name of a multipart/form-data field.
 * @example "example-field-name"
 * @minLength 1
 * @pattern ^.*$
 */
export type MultipartFormDataFieldName = string;

/**
 * Upload User ID.
 * @example "BC8048E8-A6F4-40CD-BFA2-1081049AA1AB"
 * @minLength 36
 * @maxLength 36
 * @pattern ^\S(.*?\S)?$
 */
export type UserIdUnboxed = string;

/**
 * Upload Account ID.
 * @example "A623uY2"
 * @minLength 7
 * @maxLength 7
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type AccountIdUnboxed = string; // Sync with: AccountIdUtils, AccountIdPattern, AccountIdMaxLength

/**
 * Nonce for the subscription the user is about to create.
 * @example "D812fa81A623uY2RXnNq1vfw13A63uYeFkD812fDAuY28eaFk8"
 * @minLength 50
 * @maxLength 50
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type SubscriptionNonceUnboxed = string; // Sync with: SubscriptionNonceService.nonceLength

/**
 * File uniquifier.
 * @example "Kd759aLFxttm69kZ"
 * @minLength 16
 * @maxLength 16
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type FileUniquifierUnboxed = string;

/**
 * File ID.
 * @example "W142hJkKd759aLFxttm69kZ"
 * @minLength 23
 * @maxLength 23
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type FileIdUnboxed = string;

/**
 * Size in bytes (big).
 * @example "856974744186387529544875589443785995421"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\d*$
 */
export type BigSizeInBytesUnboxed = string;

/**
 * File tag, to help organize uploaded files.
 * @example "images/profile"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-zA-Z0-9\.,/=_+-]*$
 */
export type FileTagNameUnboxed = string; // Sync with: FileTagUtils.fileTagMaxLength AND FileTagUtils.pattern AND upload-website AND TagScopeUnboxed

/**
 * If true performs a prefix search using the fileTag, else performs an exact-match search.
 * @example true
 */
export type FileTagPrefixSearchUnboxed = boolean;

/**
 * File MIME type.
 * @example "image/jpeg"
 * @minLength 3
 * @maxLength 255
 * @pattern ^[a-z0-9]+/[a-z0-9+\-._]+$
 */
export type MimeTypeUnboxed = string; // Sync with: upload-js/normalizeMimeType

/**
 * File name.
 * @example "example.jpg"
 * @minLength 1
 * @maxLength 255
 * @pattern ^.+$
 */
export type FileNameUnboxed = string;

/**
 * File ETag.
 * @example "33a64df551425fcc55e4d42a148795d9f25f89d4"
 * @minLength 1
 * @maxLength 255
 * @pattern ^\S*$
 */
export type ETagUnboxed = string;

/**
 * Number of parts the file will be uploaded in.
 * @example 12
 * @isInt
 * @minimum 1
 */
export type FilePartCountUnboxed = number;

/**
 * Index of an uploadable file part.
 * @example 7
 * @isInt
 * @minimum 0
 */
export type UploadPartIndexUnboxed = number;

/**
 * Pre-signed upload URL for this part.
 * @example "https://...long-url...x-id=PutObject"
 * @minLength 10
 */
export type PreSignedUploadUrlUnboxed = string;

/**
 * Drive ID.
 * @example 742238
 * @isInt
 * @minimum 0
 */
export type DriveIdUnboxed = number;

/**
 * Drive URL slug.
 * @example "private"
 * @minLength 1
 * @maxLength 20
 * @pattern ^[a-z0-9-+~]+$
 */
export type DriveUrlSlugUnboxed = string; // Sync with: upload-website/Patterns

/**
 * Drive name.
 * @example "Private"
 * @minLength 1
 * @maxLength 20
 * @pattern ^\S(.*?\S)?$
 */
export type DriveNameUnboxed = string;

/**
 * Drive description.
 * @example "Private"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\S(.*?\S)?$
 */
export type DriveDescriptionUnboxed = string;

/**
 * URL for an http(s) resource.
 * @example "https://localhost/foo"
 * @minLength 1
 * @maxLength 255
 * @pattern ^https?://(www\.)?[-a-zA-Z0-9\x40:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()\x40:%_\+.~#?&//=*]*)$
 */
export type HttpUrlUnboxed = string;

/**
 * Domain name.
 * @example "localhost"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-z0-9-\.]*$
 */
export type DomainNameUnboxed = string;

/**
 * Custom domain name.
 * @example "acme.com"
 * @minLength 1
 * @maxLength 255
 * @pattern ^([a-z0-9-]+\.)+[a-z]{2,}$
 */
export type CustomDomainNameUnboxed = string;

/**
 * Custom domain name target.
 * @example "xyz.upcdn.io"
 * @minLength 1
 * @maxLength 255
 * @pattern ^([a-z0-9-]+\.)+[a-z]{2,}$
 */
export type CustomDomainNameTargetDomainUnboxed = string;

/**
 * JSON Web Token (JWT).
 * @example "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiJ4In0.fiX9xWK-9af81KNXzUT_PARqLr9S43OS5iZI7MvLAYk"
 * @pattern ^[a-zA-Z0-9\-_]+?\.[a-zA-Z0-9\-_]+?\.([a-zA-Z0-9\-_]+)?$
 */
export type JwtUnboxed = string; // Sync with: JwtUtils

/**
 * Paddle plan ID.
 * @example 742238
 * @isInt
 * @minimum 0
 */
export type PaddlePlanIdUnboxed = number;

/**
 * Transformation-relative path to a file.
 * @example "/foo/bar"
 * @pattern ^/(?:((?!\.*[/\\]).)((?![/\\]\.*[/\\]).)*)?$
 */
export type TransformationArtifactPathUnboxed = string; // Sync with: FileApiRequest.transformationUrlArtifactRegexUnanchored

/**
 * First name of a person.
 * @example "Mark"
 * @minLength 1
 * @maxLength 35
 * @pattern ^\S(.*?\S)?$
 */
export type FirstNameUnboxed = string;

/**
 * Last name of a person.
 * @example "Smith"
 * @minLength 1
 * @maxLength 35
 * @pattern ^\S(.*?\S)?$
 */
export type LastNameUnboxed = string;

// See: https://github.com/lukeautry/tsoa/issues/621#issuecomment-699642005
// Explanation: '\u0040' is required because '@' causes the example to be elided.
/**
 * Email address.
 * @example "mark.smith\u0040example.com"
 * @minLength 1
 * @maxLength 254
 * @pattern ^\S+\x40\S+\.\S+$
 */
export type EmailAddressUnboxed = string;

/**
 * Organization name.
 * @example "Acme Corp"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\S(.*?\S)?$
 */
export type OrganizationNameUnboxed = string;

/**
 * Department name.
 * @example "Software Development"
 * @minLength 1
 * @maxLength 100
 * @pattern ^\S(.*?\S)?$
 */
export type DepartmentNameUnboxed = string;

/**
 * Seconds.
 * @example 60
 * @isInt
 * @minimum 0
 */
export type SecondsUnboxed = number;

/**
 * Epoch milliseconds (since midnight 1 January 1970, UTC).
 * @example 1615680311115
 * @isInt
 * @minimum 0
 */
export type EpochMillisUnboxed = number;

/**
 * Description or notes about a rule.
 * @example "max_uploads_per_ip_daily"
 * @minLength 1
 * @maxLength 40
 * @pattern ^\S(.*?\S)?$
 */
export type RuleNameUnboxed = string;

/**
 * Description or notes about a rule.
 * @example "Max 1000 uploads every 24 hours (per IP)"
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S(.*?\S)?$
 */
export type RuleDescriptionUnboxed = string;

/**
 * Error to display when rule is triggered.
 * @example "Your IP has reached its daily upload limit."
 * @minLength 1
 * @maxLength 200
 * @pattern ^\S(.*?\S)?$
 */
export type RuleErrorMessageUnboxed = string;

/**
 * Error to display when a file has expired.
 * @example "This file has expired"
 * @minLength 1
 * @maxLength 200
 * @pattern ^\S(.*?\S)?$
 */
export type FileExpiredMessageUnboxed = string;

/**
 * Description or notes about an API key.
 * @example "Production API key"
 * @minLength 1
 * @maxLength 50
 * @pattern ^\S(.*?\S)?$
 */
export type ApiKeyDescriptionUnboxed = string;

/**
 * Public API key (can be used in frontend code).
 * @example "public_A623uY2RvnNq1vZ80fYgGyhKN0U7"
 * @minLength 35
 * @maxLength 35
 * @pattern ^public_[1-9A-HJ-NP-Za-km-z]*$
 */
export type PublicApiKeyUnboxed = string;

/**
 * Secret API key (do not use in frontend code).
 * @example "secret_A623uY2RvkUy789gT8jHamNd89qa"
 * @minLength 35
 * @maxLength 35
 * @pattern ^secret_[1-9A-HJ-NP-Za-km-z]*$
 */
export type SecretApiKeyUnboxed = string;

/**
 * API key.
 * @example "secret_A623uY2RvkUy789gT8jHaPLmNd8a"
 * @minLength 35
 * @maxLength 35
 * @pattern ^(public|secret)_[1-9A-HJ-NP-Za-km-z]*$
 */
export type ApiKeyUnboxed = string; // Sync with 'PublicApiKeyUnboxed' and 'SecretApiKeyUnboxed'

/**
 * API key type.
 * @example "secret"
 * @pattern ^(public|secret)$
 */
export type ApiKeyTypeUnboxed = "public" | "secret"; // Sync with 'PublicApiKeyUnboxed' and 'SecretApiKeyUnboxed'

/**
 * Username of package maintainer on NPM.
 * @example "upload-io"
 * @minLength 1
 * @maxLength 50
 * @pattern ^[0-9A-Za-z-_.]*$
 */
export type NpmUsernameUnboxed = string;

/**
 * NPM package name.
 * @example "upload-compression-plugin"
 * @minLength 1
 * @maxLength 100
 * @pattern ^[0-9A-Za-z-_.\x40\/]*$
 */
export type NpmPackageNameUnboxed = string;

/**
 * Semantic version.
 * @example "1.2.0"
 * @minLength 1
 * @maxLength 50
 * @pattern ^([0-9]+)\.([0-9]+)\.([0-9]+)(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+[0-9A-Za-z-]+)?$
 */
export type SemanticVersionUnboxed = string;

/**
 * Description for an Upload Plugin.
 * @example "Archives, compresses and decompresses files."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S(.*?\S)?$
 */
export type PluginDescriptionUnboxed = string;

/**
 * Category for a transformation template.
 * @example "Image"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S(.*?\S)?$
 */
export type TemplateCategoryUnboxed = string;

/**
 * Codename for a template that is unique within the scope of a specific plugin version.
 * @example "compress"
 * @minLength 1
 * @maxLength 100
 * @pattern ^.*?$
 */
export type TemplateKeyUnboxed = string;

/**
 * Name for a transformation template.
 * @example "Compress a file"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S(.*?\S)?$
 */
export type TemplateNameUnboxed = string;

/**
 * Description for a transformation template.
 * @example "Compresses the file into a ZIP at a given compression level."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S(.*?\S)?$
 */
export type TemplateDescriptionUnboxed = string; // Should (but doesn't have to) match 'TransformationDescriptionUnboxed'

/**
 * Label for a transformation template parameter.
 * @example "Compression format"
 * @minLength 1
 * @maxLength 30
 * @pattern ^\S(.*?\S)?$
 */
export type TemplateParamLabelUnboxed = string;

/**
 * Transformation definition ID.
 * @example "F91kfA1g"
 * @minLength 8
 * @maxLength 8
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type TransformationDefinitionIdUnboxed = string;

/**
 * Public key ID.
 * @example "F91kfA1g"
 * @minLength 8
 * @maxLength 8
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type PublicKeyIdUnboxed = string;

/**
 * Name given to a public key.
 * @example "Public Key (www.upload.io)"
 * @minLength 1
 * @maxLength 40
 * @pattern ^\S(.*?\S)?$
 */
export type PublicKeyNameUnboxed = string;

/**
 * Public key certificate. Keys up to 4096-bit are supported.
 * @example "-----BEGIN PUBLIC KEY-----\u000A...\u000A-----END PUBLIC KEY-----"
 * @minLength 1
 * @maxLength 800
 * @pattern ^-----BEGIN .*?PUBLIC KEY-----.*?-----END .*?PUBLIC KEY-----$
 */
export type PublicKeyPEMUnboxed = string;

/**
 * Base64-encoded string.
 * @example "aGVsbG8="
 * @pattern ^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$
 */
export type Base64Unboxed = string;

/**
 * Base58-encoded string.
 * @example "aGVsbG8k"
 * @pattern ^[1-9A-HJ-NP-Za-km-z]*$
 */
export type Base58Unboxed = string;

/**
 * Description given to a transformation.
 * @example "Compresses the file into a ZIP at level 9 compression."
 * @minLength 1
 * @maxLength 80
 * @pattern ^\S(.*?\S)?$
 */
export type TransformationDescriptionUnboxed = string;

/**
 * MIME type scope, e.g. for a transformation definition.
 * @example "*"
 * @minLength 1
 * @maxLength 255
 * @pattern ^(?:\*|[a-z0-9]+\/(?:[a-z0-9+\-._]+|[a-z0-9+\-._]*\*))$
 */
export type MimeScopeUnboxed = string;

/**
 * File tag scope, e.g. for a transformation definition, a CDN download access token, or an API key's tag whitelist.
 * @example "*"
 * @minLength 1
 * @maxLength 255
 * @pattern ^[a-zA-Z0-9\.,/=_+-]*\*?$
 */
export type TagScopeUnboxed = string; // Sync with upload-website

/**
 * Identifies the location to save/load transformed files to/from.
 * @example "compressed-files-v1"
 * @minLength 8
 * @maxLength 8
 * @pattern ^[a-zA-Z0-9-]*$
 */
export type CacheIdUnboxed = string;

/**
 * Transformation URL slug (excludes the leading forward-slash).
 * @example "resize:800x600"
 * @minLength 1
 * @maxLength 100
 * @pattern ^[a-zA-Z0-9-_+=\x40~;%][a-zA-Z0-9-_.+=\x40~;%]*$
 */
export type TransformationUrlSlugUnboxed = string; // Sync with 'FileApiRequest.transformationUrlSlugRegexUnanchored'

/**
 * @minItems 1
 */
export type NonEmptyArrayUnboxed<T> = T[];

/**
 * @uniqueItems true
 * @minItems 1
 */
export type NonEmptySetUnboxed<T> = T[];

/**
 * Continuation token (aka pagination cursor).
 * @example "W142hJkKd759aLFxttm69kZ..."
 * @minLength 1
 * @maxLength 1000
 * @pattern ^\S(.*?\S)?$
 */
export type ContinuationTokenUnboxed = string;

/**
 * Page size (i.e. maximum items to return in a page of results).
 * @example 12
 * @isInt
 * @minimum 3
 * @maximum 20
 */
export type PageSizeUnboxed = number;

/**
 * Non-negative integer.
 * @example 42
 * @isInt
 * @minimum 0
 */
export type NonNegativeIntUnboxed = number;

/**
 * Account member role.
 */
export type AccountMemberRoleUnboxed = "AccountAdmin" | "AccountObserver";
